@@ -30,6 +30,9 @@ import pyecvl.ecvl as ecvl
 
 
 def main(args):
+    if not ecvl.ECVL_WITH_OPENSLIDE:
+        print("No OpenSlide support - quitting")
+        sys.exit(0)
     head, _ = os.path.splitext(os.path.basename(args.in_fn))
     levels = ecvl.OpenSlideGetLevels(args.in_fn)
     # for each level, extract a region with size = size of the last level
